scanner_document library
Classes
- IosScannerOptions
- Different options that modify the behavior of the document scanner on iOS.
- ScannerDocument
- A Flutter plugin for scanning documents with automatic edge detection and cropping.
Enums
- IosImageFormat
- Enumerates the different output image formats are supported.